@@ -19,39 +19,44 @@ class LoadDataKline:
             if ':' not in sym:
                 self.load(sym, *args, **kwargs)
 
-    def load(self, symbol, timeframe='1m', max_retries=3, *args, **kwargs):
+    def load(self, symbol, timeframe='1m', max_retries=3, limit=720, *args, **kwargs):
         max_time, min_time = self.table.select_symbol_maxmin(symbol)
-
-        limit = 720
-        earliest_timestamp = self.exchange.milliseconds()
-
-        print(min_time, earliest_timestamp)
-
-        timeframe_duration_in_seconds = self.exchange.parse_timeframe(timeframe)
-        timeframe_duration_in_ms = timeframe_duration_in_seconds * 1000
+        timeframe_duration_in_ms = self.exchange.parse_timeframe(timeframe) * 1000
         timedelta = limit * timeframe_duration_in_ms
-        result_dictionary = {}
 
-        pbar = tqdm(range(100), desc=symbol)
-        for _ in pbar:
-            fetch_since = earliest_timestamp - timedelta
+        def load(fetch_since):
             result = self.exchange.fetch_ohlcv(symbol, timeframe, fetch_since, limit)
+            result = self.exchange.sort_by(result, 0)
 
             if len(result) == 0:
-                continue
+                return False, 'result is empty'
             pbar.set_postfix({'fetch_since': self.exchange.iso8601(result[0][0])})
-            result_dictionary = self.exchange.extend(result_dictionary, self.exchange.indexBy(result, 0))
-            result_list = self.exchange.sort_by(result_dictionary.values(), 0)
-
-            if len(result_list) == 0:
-                continue
-
-            df = pd.DataFrame(result_list, columns=['timestamp', 'open', 'close', 'low', 'high', 'vol'])
+            df = pd.DataFrame(result, columns=['timestamp', 'open', 'close', 'low', 'high', 'vol'])
             df['symbol'] = symbol
             self.table.insert(json.loads(df.to_json(orient='records')))
-            earliest_timestamp = result[0][0] - timeframe_duration_in_ms
+            return True, result
+
+        earliest_timestamp = min_time
+        pbar = tqdm(range(100), desc=symbol)
+        for _ in pbar:
+            status, result = load(earliest_timestamp - timedelta)
+            if status is False:
+                print(result)
+                break
+            earliest_timestamp = result[0][0]
+
+        #earliest_timestamp = self.exchange.milliseconds()
+        lasted_timestamp = max_time
+        pbar = tqdm(range(100), desc=symbol)
+        for _ in pbar:
+            status, result = load(lasted_timestamp)
+            if status is False:
+                print(result)
+                break
+            lasted_timestamp = result[-1][0]
 
 
+exchan = LoadDataKline(ccxt.okex())
 # exchan.load('BTC/USDT')
 # exchan.load('BTC/USDT')
 exchan.load_all()
